;;; bandali-dired.el --- bandali's dired setup       -*- lexical-binding: t; -*-

;; Copyright (C) 2018-2020  Amin Bandali

;; Author: Amin Bandali <bandali@gnu.org>
;; Keywords: files

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; My dired setup and customizations.

;;; Code:

(use-package dired
  :config
  (setq dired-dwim-target t
        dired-listing-switches "-alh"
        ls-lisp-use-insert-directory-program nil)

  ;; easily diff 2 marked files
  ;; https://oremacs.com/2017/03/18/dired-ediff/
  (defun dired-ediff-files ()
    (interactive)
    (require 'dired-aux)
    (defvar ediff-after-quit-hook-internal)
    (let ((files (dired-get-marked-files))
          (wnd (current-window-configuration)))
      (if (<= (length files) 2)
          (let ((file1 (car files))
                (file2 (if (cdr files)
                           (cadr files)
                         (read-file-name
                          "file: "
                          (dired-dwim-target-directory)))))
            (if (file-newer-than-file-p file1 file2)
                (ediff-files file2 file1)
              (ediff-files file1 file2))
            (add-hook 'ediff-after-quit-hook-internal
                      (lambda ()
                        (setq ediff-after-quit-hook-internal nil)
                        (set-window-configuration wnd))))
        (error "no more than 2 files should be marked"))))

  (require 'dired-x)
  (setq dired-guess-shell-alist-user
        '(("\\.pdf\\'"  "evince" "zathura" "okular")
          ("\\.doc\\'"  "libreoffice")
          ("\\.docx\\'" "libreoffice")
          ("\\.ppt\\'"  "libreoffice")
          ("\\.pptx\\'" "libreoffice")
          ("\\.xls\\'"  "libreoffice")
          ("\\.xlsx\\'" "libreoffice")
          ("\\.flac\\'" "mpv")))
  :bind (:map dired-mode-map
              ("b"  . dired-up-directory)
              ("E"  . dired-ediff-files)
              ("e"  . dired-toggle-read-only)
              ("\\" . dired-hide-details-mode)
              ("z"  . (lambda ()
                        (interactive)
                        (b/dired-start-process "zathura"))))
  :hook (dired-mode . dired-hide-details-mode))

(provide 'bandali-dired)
;;; bandali-dired.el ends here
